
From: Olaf Hering <olh@suse.de>

A few users of request_irq pass a string with '/'.
As a result, ls -l /proc/irq/*/* will fail to list these entries.

Signed-off-by: Olaf Hering <olh@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/input/serio/maceps2.c     |    2 +-
 25-akpm/drivers/macintosh/via-pmu.c       |    2 +-
 25-akpm/drivers/net/wan/hostess_sv11.c    |    2 +-
 25-akpm/include/asm-sh/mpc1211/keyboard.h |    2 +-
 25-akpm/include/asm-sh64/keyboard.h       |    2 +-
 25-akpm/sound/isa/opl3sa2.c               |    2 +-
 6 files changed, 6 insertions(+), 6 deletions(-)

diff -puN drivers/input/serio/maceps2.c~request_irq-avoid-slash-in-proc-directory-entries drivers/input/serio/maceps2.c
--- 25/drivers/input/serio/maceps2.c~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.290386976 -0800
+++ 25-akpm/drivers/input/serio/maceps2.c	2005-01-05 15:38:06.330380896 -0800
@@ -90,7 +90,7 @@ static int maceps2_open(struct serio *de
 {
 	struct maceps2_data *data = (struct maceps2_data *)dev->port_data;
 
-	if (request_irq(data->irq, maceps2_interrupt, 0, "PS/2 port", dev)) {
+	if (request_irq(data->irq, maceps2_interrupt, 0, "PS2 port", dev)) {
 		printk(KERN_ERR "Could not allocate PS/2 IRQ\n");
 		return -EBUSY;
 	}
diff -puN drivers/macintosh/via-pmu.c~request_irq-avoid-slash-in-proc-directory-entries drivers/macintosh/via-pmu.c
--- 25/drivers/macintosh/via-pmu.c~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.306384544 -0800
+++ 25-akpm/drivers/macintosh/via-pmu.c	2005-01-05 15:38:06.332380592 -0800
@@ -418,7 +418,7 @@ static int __init via_pmu_start(void)
 	}
 
 	if (pmu_kind == PMU_KEYLARGO_BASED && gpio_irq != -1) {
-		if (request_irq(gpio_irq, gpio1_interrupt, 0, "GPIO1/ADB", (void *)0))
+		if (request_irq(gpio_irq, gpio1_interrupt, 0, "GPIO1 ADB", (void *)0))
 			printk(KERN_ERR "pmu: can't get irq %d (GPIO1)\n", gpio_irq);
 		gpio_irq_enabled = 1;
 	}
diff -puN drivers/net/wan/hostess_sv11.c~request_irq-avoid-slash-in-proc-directory-entries drivers/net/wan/hostess_sv11.c
--- 25/drivers/net/wan/hostess_sv11.c~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.307384392 -0800
+++ 25-akpm/drivers/net/wan/hostess_sv11.c	2005-01-05 15:38:06.333380440 -0800
@@ -263,7 +263,7 @@ static struct sv11_device *sv11_init(int
 	/* We want a fast IRQ for this device. Actually we'd like an even faster
 	   IRQ ;) - This is one driver RtLinux is made for */
 	   
-	if(request_irq(irq, &z8530_interrupt, SA_INTERRUPT, "Hostess SV/11", dev)<0)
+	if(request_irq(irq, &z8530_interrupt, SA_INTERRUPT, "Hostess SV11", dev)<0)
 	{
 		printk(KERN_WARNING "hostess: IRQ %d already in use.\n", irq);
 		goto fail1;
diff -puN include/asm-sh64/keyboard.h~request_irq-avoid-slash-in-proc-directory-entries include/asm-sh64/keyboard.h
--- 25/include/asm-sh64/keyboard.h~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.309384088 -0800
+++ 25-akpm/include/asm-sh64/keyboard.h	2005-01-05 15:38:06.333380440 -0800
@@ -65,7 +65,7 @@ extern unsigned char pckbd_sysrq_xlate[1
 #endif
 
 #define aux_request_irq(hand, dev_id)					\
-	request_irq(AUX_IRQ, hand, SA_SHIRQ, "PS/2 Mouse", dev_id)
+	request_irq(AUX_IRQ, hand, SA_SHIRQ, "PS2 Mouse", dev_id)
 
 #define aux_free_irq(dev_id) free_irq(AUX_IRQ, dev_id)
 
diff -puN include/asm-sh/mpc1211/keyboard.h~request_irq-avoid-slash-in-proc-directory-entries include/asm-sh/mpc1211/keyboard.h
--- 25/include/asm-sh/mpc1211/keyboard.h~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.319382568 -0800
+++ 25-akpm/include/asm-sh/mpc1211/keyboard.h	2005-01-05 15:38:06.333380440 -0800
@@ -57,7 +57,7 @@ extern unsigned char pckbd_sysrq_xlate[1
 #define AUX_IRQ 12
 
 #define aux_request_irq(hand, dev_id)					\
-	request_irq(AUX_IRQ, hand, SA_SHIRQ, "PS/2 Mouse", dev_id)
+	request_irq(AUX_IRQ, hand, SA_SHIRQ, "PS2 Mouse", dev_id)
 
 #define aux_free_irq(dev_id) free_irq(AUX_IRQ, dev_id)
 
diff -puN sound/isa/opl3sa2.c~request_irq-avoid-slash-in-proc-directory-entries sound/isa/opl3sa2.c
--- 25/sound/isa/opl3sa2.c~request_irq-avoid-slash-in-proc-directory-entries	2005-01-05 15:38:06.326381504 -0800
+++ 25-akpm/sound/isa/opl3sa2.c	2005-01-05 15:38:06.334380288 -0800
@@ -711,7 +711,7 @@ static int __devinit snd_opl3sa2_probe(i
 		chip->single_dma = 1;
 	if ((err = snd_opl3sa2_detect(chip)) < 0)
 		goto __error;
-	if (request_irq(xirq, snd_opl3sa2_interrupt, SA_INTERRUPT, "OPL3-SA2/3", (void *)chip)) {
+	if (request_irq(xirq, snd_opl3sa2_interrupt, SA_INTERRUPT, "OPL3-SA2", (void *)chip)) {
 		snd_printk(KERN_ERR "opl3sa2: can't grab IRQ %d\n", xirq);
 		err = -ENODEV;
 		goto __error;
_
